/*********************************************************************************************

	WRITTEN BY: MATTHEW STAIGER
		Identifies parent-child relationships from i) 2000 and 2010 Decennial Census files
		for all states, and ii) ACS data files from 2001-2017. Uses these relationship,
		along with the date of birth of the child, to identify the birth dates and birth
		order of children within each household, including PIKs for both parents in the
		household. 
	
	OUTPUT DATASET: parentchild
		VARIABLES: pik_head pik_partner marital_status birth_qtime birth_date
		birth_order source mafid
		length pik $9 birth_qtime 3 birth_order 3 marital_status $1 pik_partner $9;
		
	NOTES ON KEY VARIABLES

	rel: relationship codes for 2018 acs
		0=reference person
		1=husband/wife
		2=biological son/daughter
		3=adopted son/daughter
		4=stepson/setpdaughter
		5=brother/sister
		6=father/mother
		7=grandchild
		8=parent-in-law
		9=son/daugther-in-law
		10=other relative
		11=roomer/boarder
		12=househomate/roomamate
		13=unmarried partner
		14=foster child
		15=other nonrelative
*********************************************************************************************/

*define last ACS year;
%let lastacsyear=2017;

*2000 DECENNIAL CENSUS;
*-----------------------------------------------------------------------*;
%macro cen00data;
*summarize input data;
PROC CONTENTS DATA=cenx00.census_2000_pik_xwalk_dwh;
RUN;

PROC CONTENTS DATA=cen00.cen2000hdf_or_03;
RUN;

*create national decennial file;
DATA cen00;	
	SET cen00.cen2000hdf_ak_03(OBS=&sample_size. 
		KEEP=puid pnc qrel qdb qsex
		RENAME=(puid=mafid) );
RUN;

%let statelist = al ar az ca co ct dc de fl ga hi ia id il in ks ky la ma md
	me mi mn mo ms mt nc nd ne nh nj nm nv oh ok or pa pr ri sc sd tn tx ut 
	va vt wa wi wv wy;
%let length=%sysfunc(countw(&statelist.));
%DO i=1 %TO &length.;
%let st=%scan(&statelist.,&i.);
DATA cen00;	
	SET cen00
		cen00.cen2000hdf_&st._03(OBS=&sample_size. 
			KEEP=puid pnc qrel qdb qsex
			RENAME=(puid=mafid) );
RUN;
%END;

*there should be no duplicates here;
PROC SORT DATA=cen00(WHERE=(mafid^="")) NODUPKEY;
	BY mafid pnc;
RUN;

*tabulate relationship and sex code;
PROC FREQ DATA=cen00;
	TITLE "relationship and sex codes in 2000 decennial file";
	TABLES qrel qsex /MISSING;
RUN;

*there should by no duplicates here;
PROC SORT DATA=cenx00.census_2000_pik_xwalk_dwh(OBS=&sample_size.  
		KEEP=mafid pnc pik) 
		OUT=xwalk NODUPKEY;
	BY mafid pnc;
RUN;

DATA cen00;
	MERGE cen00(IN=source_cen00) xwalk(IN=source_xwalk KEEP=mafid pnc pik);
	BY mafid pnc;
	IF source_cen00^=1 THEN DELETE;
	_merge = source_cen00+2*source_xwalk;
RUN;

PROC FREQ DATA=cen00;
	TITLE "merge rate between 2000 decennial and pik crosswalk";
	TABLES _merge /MISSING;
RUN;

*create dataset of children;
DATA child(KEEP=mafid birth_qtime birth_date);
	LENGTH birth_qtime 3;
	SET cen00(OBS=&sample_size. KEEP=mafid qrel qdb
		WHERE = (qrel='03'));
	dbm = SUBSTR(qdb,5,2);
	dbm=input(dbm,8.);
	dby = SUBSTR(qdb,1,4);
	dby=input(dby,8.);
	dbd = SUBSTR(qdb,7,2);
	dbd=input(dbd,8.);
	qob = .;
		IF dbm>=1 AND dbm<=3 THEN qob=1;
		IF dbm>=4 AND dbm<=6 THEN qob=2;
		IF dbm>=7 AND dbm<=9 THEN qob=3;
		IF dbm>=10 AND dbm<=12 THEN qob=4;
	birth_qtime=(dby-1985)*4+qob;
	birth_date = mdy(dbm,dbd,dby);
	FORMAT birth_date mmddyy10.;
RUN;

*birth order;
PROC SORT DATA=child;
	BY mafid birth_qtime birth_date;
RUN;

DATA child(KEEP=mafid birth_qtime birth_date birth_order);
	LENGTH birth_order 3;
	SET child;
	BY mafid;
	counter+1;
	IF FIRST.mafid THEN counter=1;
	birth_order=counter;
RUN;

*retain one birth per qtime;
PROC SORT DATA=child NODUPKEY;
	BY mafid birth_qtime;
RUN;

*marital status;
PROC SORT DATA=cen00(KEEP=mafid qrel qsex WHERE=(qrel="01" OR qrel="02"))
		OUT=mar NODUPKEY;
	BY mafid qrel;
RUN;

DATA mar(KEEP=mafid marital_status);
	LENGTH marital_status $1;
	MERGE mar(IN=source_head 
			RENAME=(qrel=qrel_head qsex=qsex_head) WHERE=(qrel_head="01"))
		mar(IN=source_spouse
			RENAME=(qrel=qrel_spouse qsex=qsex_spouse) WHERE=(qrel_spouse="02"));
	BY mafid;
	marital_status="U";
	IF source_head=1 AND source_spouse=1 THEN marital_status="M";
	*drop same sex couples;
	IF qsex_head=qsex_spouse THEN DELETE;
RUN;

*there should be no duplicates here;
PROC SORT DATA=mar NODUPKEY;
	BY mafid;
RUN;

*drop missing or duplicate piks;
PROC SORT DATA=cen00(WHERE=(pik^="" AND _merge=3)) 
		OUT=cen00 DUPOUT=dups(KEEP=pik) NODUPKEY;
	BY pik;
RUN;

PROC SORT DATA=dups NODUPKEY;
	BY pik;
RUN;

DATA cen00(KEEP=mafid pik qrel);
	MERGE cen00(IN=source_cen00) dups(IN=source_dups);
	BY pik;
	IF source_cen00^=1 OR source_dups=1 
		OR (qrel^='01' AND qrel^='02') THEN DELETE;
RUN;

*create dataset with household head;
DATA head(KEEP=mafid pik);
	SET cen00(OBS=&sample_size. KEEP=mafid pik qrel
		WHERE = (qrel='01'));
RUN;

*there should be no duplicates here;
PROC SORT DATA=head NODUPKEY;
	BY mafid;
RUN;

DATA partner(KEEP=mafid pik);
	SET cen00(OBS=&sample_size. KEEP=mafid pik qrel
		WHERE = (qrel='02'));
RUN;

*there should be no duplicates here;
PROC SORT DATA=partner NODUPKEY;
	BY mafid;
RUN;

DATA head;
	LENGTH hh_head $1.;
	MERGE head(IN=source_head)
		partner(IN=source_partner KEEP=mafid pik RENAME=(pik=pik_partner));
	BY mafid;
	IF source_head^=1 THEN DELETE;
	hh_head='1';
RUN;

DATA partner;
	LENGTH hh_head $1.;
	MERGE partner(IN=source_partner) 
		head(IN=source_head KEEP=mafid pik RENAME=(pik=pik_partner));
	BY mafid;
	IF source_partner^=1 THEN DELETE;
	hh_head='0';
RUN;

*create childparent data;
DATA head;
	MERGE head(IN=source_head) child(IN=source_child) mar(IN=source_mar);
	BY mafid;
	IF source_head^=1 OR source_child^=1 OR source_mar^=1 THEN DELETE;
RUN;

DATA partner;
	MERGE partner(IN=source_partner) child(IN=source_child) mar(IN=source_mar);
	BY mafid;
	IF source_partner^=1 OR source_child^=1 OR source_mar^=1 THEN DELETE;
RUN;

DATA parentchild(KEEP=pik pik_partner mafid 
		birth_qtime birth_date birth_order marital_status hh_head cen00);
	LENGTH pik $9 pik_partner $9 birth_qtime 3 birth_order 3 marital_status $1 cen00 3;
	SET head partner;
	cen00=1;
RUN;

*there should be no duplicates here;
PROC SORT DATA=parentchild NODUPKEY;
	BY pik birth_qtime;
RUN;

PROC CONTENTS DATA=parentchild;
RUN;

PROC PRINT DATA=parentchild(OBS=100);
RUN;

*save to interwrk folder;
DATA interwrk.parentchild;
	SET parentchild;
RUN;

*delete all data in work library to free up memory;
PROC DATASETS LIBRARY=WORK KILL NOLIST;
RUN;

%mend cen00data;
%cen00data;

*ACS DATA;
*-----------------------------------------------------------------------*;
%macro acsdata;

%let acsdata2001 = vpers2001_1yr;
%let acsdata2002 = vpers2002_1yr;
%let acsdata2003 = vpers2003_1yr;
%let acsdata2004 = vpers2004_1yr;
%let acsdata2005 = vpers2005_1yr;
%let acsdata2006 = vpers2006_1yr;
%let acsdata2007 = vpers2007_1yr;
%let acsdata2008 = vpers2008_1yr;
%let acsdata2009 = vpers2009_1yr;
%let acsdata2010 = vpers2010_1yr;
%let acsdata2011 = vpers2011_1yr;
%let acsdata2012 = vpers2012_1yr;
%let acsdata2013 = vpers2013_1yr;
%let acsdata2014 = vpers2014_1yr;
%let acsdata2015 = vpers2015_1yr;
%let acsdata2016 = acs2016_vpers_1yr;
%let acsdata2017 = acs2017_vpers_1yr;
%let acsdata2018 = acs2018_vpers_1yr;

%DO yr=2001 %TO &lastacsyear.;

*summarize input data;
PROC CONTENTS DATA=acs&yr..&&acsdata&yr;
RUN;

PROC CONTENTS DATA=acsx&yr..crosswalk_acs&yr.;
RUN;

*there should be no duplicates here;
PROC SORT DATA=acs&yr..&&acsdata&yr(OBS=&sample_size. 
		KEEP=cmid pnum rel dbd dbm dby sex)
		OUT=acs 
		NODUPKEY;
	BY cmid pnum;
RUN;

PROC FREQ DATA=acs;
	TITLE "tabulate relationship and sex codes from acs";
	TABLES rel sex /MISSING;
RUN;

PROC SORT DATA=acsx&yr..crosswalk_acs&yr.(OBS=&sample_size.)
		OUT=acsxwalk
		NODUPKEY;
	BY cmid pnum;
RUN;

DATA acs(KEEP=cmid pnum rel dbd dbm dby pik mafid sex _merge);
	LENGTH pnum 8;
	MERGE acs(IN=source_acs) acsxwalk(IN=source_xwalk);
	BY cmid pnum;
	IF source_acs^=1 THEN DELETE;
	_merge = source_acs+2*source_xwalk;
	rel=COMPRESS(rel);
	*no mafid on pre 2010 files so use the cmid;
	%IF &yr.<2010 %THEN %DO;
		mafid=cmid;
	%END;
RUN;

PROC FREQ DATA=acs;
	TITLE "merge rate (1=acs, 2=xwalk, 3=merge)";
	TABLES _merge /MISSING;
RUN;

*marital status;
PROC SORT DATA=acs(KEEP=cmid rel sex WHERE=(rel="0" OR rel="1"))
	OUT=mar NODUPKEY;
	BY cmid rel;
RUN;

DATA mar(KEEP=cmid marital_status);
	LENGTH marital_status $1;
	MERGE mar(IN=source_head RENAME=(rel=rel_head sex=sex_head) WHERE=(rel_head="0"))
		mar(IN=source_spouse RENAME=(rel=rel_spouse sex=sex_spouse) WHERE=(rel_spouse="1"));
	BY cmid;
	marital_status="U";
	IF source_head=1 AND source_spouse=1 THEN marital_status="M";
	*drop same sex couples;
	IF sex_head=sex_spouse THEN DELETE;
RUN;

*there should be no duplicates here;
PROC SORT DATA=mar NODUPKEY;
	BY cmid;
RUN;

*drop parents with duplicates piks;
PROC SORT DATA=acs(WHERE=(_merge=3 AND pik^='')) 
		OUT=parents DUPOUT=dups(KEEP=pik) NODUPKEY;
	BY pik;
RUN;

PROC SORT DATA=dups NODUPKEY;
	BY pik;
RUN;

DATA parents;
	MERGE parents(IN=source_sample) dups(IN=source_dups);
	BY pik;
	IF source_sample^=1 OR source_dups=1
		OR (rel^='0' AND rel^='1') THEN DELETE;
RUN;

*identify parents;
DATA head(KEEP=mafid cmid pik);
	SET parents(KEEP=mafid cmid pik rel
		WHERE = (rel='0'));
RUN;

*there should be no duplicates here;
PROC SORT DATA=head NODUPKEY;
	BY mafid;
RUN;

DATA partner(KEEP=mafid cmid pik);
	SET parents(KEEP=mafid cmid pik rel
		WHERE = (rel='1'));
RUN;

*there should be no duplicates here;
PROC SORT DATA=partner NODUPKEY;
	BY mafid;
RUN;

*combine head and partner data;
DATA partner;
	MERGE partner(IN=source_partner) 
		head(IN=source_head KEEP=mafid pik RENAME=(pik=pik_partner));
	BY mafid;
	IF source_partner^=1 THEN DELETE;
RUN;

DATA head;
	MERGE head(IN=source_head) 
		partner(IN=source_partner KEEP=mafid pik RENAME=(pik=pik_partner));
	BY mafid;
	IF source_head^=1 THEN DELETE;
RUN;

*bring in children;
DATA child(KEEP=cmid birth_qtime birth_date);
	LENGTH  birth_qtime 3;
	SET acs(KEEP=cmid rel dbd dbm dby
		WHERE = (rel='2'));
	qob = .;
		IF dbm>=1 AND dbm<=3 THEN qob=1;
		IF dbm>=4 AND dbm<=6 THEN qob=2;
		IF dbm>=7 AND dbm<=9 THEN qob=3;
		IF dbm>=10 AND dbm<=12 THEN qob=4;
	birth_qtime=(dby-1985)*4+qob;
	birth_date = mdy(dbm,dbd,dby);
	FORMAT birth_date mmddyy10.;
RUN;

PROC SORT DATA=child;
	BY cmid birth_qtime birth_date;
RUN;

*birth order;
DATA child(KEEP=cmid birth_qtime birth_date birth_order);
	LENGTH birth_order 3;
	SET child;
	BY cmid;
	counter+1;
	IF FIRST.cmid THEN counter=1;
	birth_order=counter;
RUN;

PROC FREQ DATA=child;
	TITLE "tabulate birth order";
	TABLES birth_order /MISSING;
RUN;

*retain one birth per qtime;
PROC SORT DATA=child NODUPKEY;
	BY cmid birth_qtime;
RUN;

*there should be no duplicates here;
PROC SORT DATA=head NODUPKEY;
	BY cmid;
RUN;

PROC SORT DATA=partner NODUPKEY;
	BY cmid;
RUN;

*merge children and parents;
DATA headchild;
	LENGTH hh_head $1.;
	MERGE child(IN=source_child) head(IN=source_head) mar(IN=source_mar);
	BY cmid;
	IF source_child^=1 THEN DELETE;
	_merge_head = source_child+2*source_head;
	_merge_mar = source_child+2*source_mar;
	hh_head='1';
RUN;

PROC FREQ DATA=headchild;
	TITLE "1=child only, 2=head only, 3=merge";
	TABLES _merge_head /MISSING;
RUN;

DATA partnerchild;
	LENGTH hh_head $1.;
	MERGE child(IN=source_child) partner(IN=source_partner) mar(IN=source_mar);
	BY cmid;
	IF source_child^=1 THEN DELETE;
	_merge_partner = source_child+2*source_partner;
	_merge_pmar = source_child+2*source_mar;
	hh_head='0';
RUN;

PROC FREQ DATA=partnerchild;
	TITLE "1=child only, 2=partner only, 3=merge";
	TABLES _merge_partner /MISSING;
RUN;

DATA temp(KEEP=pik pik_partner mafid 
		birth_qtime birth_date birth_order marital_status hh_head);
	LENGTH pik $9 pik_partner $9 birth_qtime 3 birth_order 3 marital_status $1;
	SET headchild(WHERE=(_merge_head=3 AND _merge_mar=3)) 
		partnerchild(WHERE=(_merge_partner=3 AND _merge_pmar=3));
RUN;

*there should be no duplicates here;
PROC SORT DATA=temp NODUPKEY;
	BY pik birth_qtime;
RUN;

PROC CONTENTS DATA=temp;
RUN;

PROC PRINT DATA=temp(OBS=20);
RUN;

*merge to full parentchild file;
DATA temp;
	MERGE temp(IN=source_sample) interwrk.parentchild(IN=source_pc KEEP=pik birth_qtime);
        LENGTH acs&yr. 3;
	BY pik birth_qtime;
	IF source_sample^=1 THEN DELETE;
	_merge  = source_sample+2*source_pc;
	acs&yr.=1;
RUN;

DATA interwrk.parentchild(DROP=_merge);
        LENGTH acs&yr. 3;
	MERGE interwrk.parentchild temp(IN=source_acs KEEP=pik birth_qtime _merge WHERE=(_merge=3));
	BY pik birth_qtime;
	acs&yr.=0;
	IF source_acs=1 THEN acs&yr.=1;
RUN;

DATA interwrk.parentchild(DROP=_merge);
	SET interwrk.parentchild temp(WHERE=(_merge=1));
RUN;

*there should be no duplicates here;
PROC SORT DATA=interwrk.parentchild NODUPKEY;
	BY pik birth_qtime;
RUN;

%END;

PROC CONTENTS DATA=interwrk.parentchild;
RUN;

PROC PRINT DATA=interwrk.parentchild(OBS=20);
RUN;

*delete all data in work library to free up memory;
PROC DATASETS LIBRARY=WORK KILL NOLIST;
RUN;

%mend acsdata;
%acsdata;

*2010 DECENNIAL CENSUS;
*-----------------------------------------------------------------------*;
%macro cen10data;

*summarize input files;
PROC CONTENTS DATA=cen10.cen2010hdf_us_p;
RUN;

*cuf_2010_crosswalk;
PROC CONTENTS DATA=cenx10.cuf_2010_enh1_crosswalk;
RUN;

PROC FREQ DATA=cen10.cen2010hdf_us_p(OBS=&sample_size. KEEP=qrel qsex);
	TITLE "relationship and sex codes in 2010 decennial file";
	TABLES qrel qsex /MISSING;
RUN;
	
*attach PIKs to decennial file;
DATA cen10;	
	LENGTH carra_uid $21;
	SET cen10.cen2010hdf_us_p(OBS=&sample_size. 
		KEEP=mafid cuf_pnc qrel colblkst qdb qsex);
	carra_uid = CATT('',colblkst,mafid,"0000",cuf_pnc);
RUN;

*there should be no duplicates;
PROC SORT DATA=cen10 NODUPKEY;
	BY carra_uid;
RUN;

PROC SORT DATA=cenx10.cuf_2010_enh1_crosswalk(OBS=&sample_size. ) OUT=xwalk NODUPKEY;
	BY carra_uid;
RUN;

DATA cen10;
	MERGE cen10(IN=source_cen10) xwalk(IN=source_xwalk KEEP=carra_uid pik);
	BY carra_uid;
	IF source_cen10^=1 THEN DELETE;
	_merge = source_cen10+2*source_xwalk;
RUN;

PROC FREQ DATA=cen10;
	TITLE "merge rate between decennial and pik crosswalk";
	TABLES _merge /MISSING;
RUN;

*create dataset of children;
DATA child(KEEP=mafid birth_qtime birth_date);
	LENGTH birth_qtime 3;
	SET cen10(OBS=&sample_size. KEEP=mafid cuf_pnc qrel qdb
		WHERE = (qrel='03'));
	dbm = SUBSTR(qdb,5,2);
	dbm=input(dbm,8.);
	dby = SUBSTR(qdb,1,4);
	dby=input(dby,8.);
	dbd = SUBSTR(qdb,7,2);
	dbd=input(dbd,8.);
	qob = .;
		IF dbm>=1 AND dbm<=3 THEN qob=1;
		IF dbm>=4 AND dbm<=6 THEN qob=2;
		IF dbm>=7 AND dbm<=9 THEN qob=3;
		IF dbm>=10 AND dbm<=12 THEN qob=4;
	birth_qtime=(dby-1985)*4+qob;
	birth_date = mdy(dbm,dbd,dby);
	FORMAT birth_date mmddyy10.;
RUN;

*birth order;
PROC SORT DATA=child;
	BY mafid birth_qtime birth_date;
RUN;

DATA child(KEEP=mafid birth_qtime birth_date birth_order);
	LENGTH birth_order 3;
	SET child;
	BY mafid;
	counter+1;
	IF FIRST.mafid THEN counter=1;
	birth_order=counter;
RUN;

*retain one birth per qtime;
PROC SORT DATA=child NODUPKEY;
	BY mafid birth_qtime;
RUN;

*marital status;
PROC SORT DATA=cen10(KEEP=mafid qrel qsex WHERE=(qrel="01" OR qrel="02"))
		OUT=mar NODUPKEY;
	BY mafid qrel;
RUN;

DATA mar(KEEP=mafid marital_status);
	LENGTH marital_status $1;
	MERGE mar(IN=source_head 
			RENAME=(qrel=qrel_head qsex=qsex_head) WHERE=(qrel_head="01"))
		mar(IN=source_spouse 
			RENAME=(qrel=qrel_spouse qsex=qsex_spouse) WHERE=(qrel_spouse="02"));
	BY mafid;
	marital_status="U";
	IF source_head=1 AND source_spouse=1 THEN marital_status="M";
	*drop same sex couples;
	IF qsex_head=qsex_spouse THEN DELETE;
RUN;

*there should be no duplicates here;
PROC SORT DATA=mar NODUPKEY;
	BY mafid;
RUN;

*drop missing or duplicate piks;
PROC SORT DATA=cen10(WHERE=(pik^="" AND _merge=3)) OUT=cen10 DUPOUT=dups(KEEP=pik) NODUPKEY;
	BY pik;
RUN;

PROC SORT DATA=dups NODUPKEY;
	BY pik;
RUN;

DATA cen10;
	MERGE cen10(IN=source_cen10) dups(IN=source_dups);
	BY pik;
	IF source_cen10^=1 OR source_dups=1 
		OR (qrel^="01" AND qrel^="02") THEN DELETE;
RUN;

*create dataset with household head;
DATA head(KEEP=mafid pik);
	SET cen10(OBS=&sample_size. KEEP=mafid pik qrel
		WHERE = (qrel='01'));
RUN;

*there should be no duplicates here;
PROC SORT DATA=head NODUPKEY;
	BY mafid;
RUN;


DATA partner(KEEP=mafid pik);
	SET cen10(OBS=&sample_size. KEEP=mafid pik qrel
		WHERE = (qrel='02'));
RUN;

*there should be no duplicates here;
PROC SORT DATA=partner NODUPKEY;
	BY mafid;
RUN;

DATA head;
	LENGTH hh_head $1.;
	MERGE head(IN=source_head) 
		partner(IN=source_partner KEEP=mafid pik RENAME=(pik=pik_partner));
	BY mafid;
	IF source_head^=1 THEN DELETE;
	hh_head='1';
RUN;

DATA partner;
	LENGTH hh_head $1.;
	MERGE partner(IN=source_partner) 
		head(IN=source_head KEEP=mafid pik RENAME=(pik=pik_partner));
	BY mafid;
	IF source_partner^=1 THEN DELETE;
	hh_head='0';
RUN;

*create childparent data;
DATA head;
	MERGE head(IN=source_head) child(IN=source_child) mar(IN=source_mar);
	BY mafid;
	IF source_head^=1 OR source_child^=1 OR source_mar^=1 THEN DELETE;
RUN;

DATA partner;
	MERGE partner(IN=source_partner) child(IN=source_child) mar(IN=source_mar);
	BY mafid;
	IF source_partner^=1 OR source_child^=1 OR source_mar^=1 THEN DELETE;
RUN;

DATA parentchild(KEEP=pik pik_partner mafid 
		birth_qtime birth_date birth_order marital_status hh_head);
	LENGTH pik $9 pik_partner $9 birth_qtime 3 birth_order 3 marital_status $1;
	SET head partner;
RUN;

*there should be no duplicates here;
PROC SORT DATA=parentchild NODUPKEY;
	BY pik birth_qtime;
RUN;

PROC CONTENTS DATA=parentchild;
RUN;

PROC PRINT DATA=parentchild(OBS=100);
RUN;

*merge back to full parent child data;
PROC SORT DATA=parentchild OUT=temp NODUPKEY;
	BY pik birth_qtime;
RUN;

DATA temp(DROP=temp);
	MERGE temp(IN=source_sample) interwrk.parentchild(IN=source_pc KEEP=pik birth_qtime cen00 acs2001-acs&lastacsyear.);
	BY pik birth_qtime;
	IF source_sample^=1 THEN DELETE;
	_merge  = source_sample+2*source_pc;
	cen10=1;
	*use decennial if earlier than ACS;
	temp=0;
	IF cen00=1 THEN temp=1;
	%DO yr=2001 %TO 2010;
		IF acs&yr.=1 THEN temp=1;
	%END;
	flag=0;
	%DO yr=2011 %TO &lastacsyear.;
		IF acs&yr.=1 AND temp=0 THEN flag=1;
	%END;
RUN;

DATA interwrk.parentchild(DROP=_merge flag);
        LENGTH cen10 3;
	MERGE interwrk.parentchild temp(IN=source_cen10 KEEP=pik birth_qtime flag _merge WHERE=(_merge=3));
	BY pik birth_qtime;
	cen10=0;
	IF source_cen10=1 THEN cen10=1;
	IF flag=1 THEN DELETE;
RUN;

DATA interwrk.parentchild(DROP=_merge flag);
	SET interwrk.parentchild temp(WHERE=(_merge=1 OR flag=1));
RUN;

*there should be no duplicates here;
PROC SORT DATA=interwrk.parentchild NODUPKEY;
	BY pik birth_qtime;
RUN;

*delete all data in work library to free up memory;
PROC DATASETS LIBRARY=WORK KILL NOLIST;
RUN;

%mend cen10data;
%cen10data;

*SUMMARIZE FINAL DATASET WITH ALL SOURCES;
*-----------------------------------------------------------------------*;
%macro finaldata;
*clean source codes and update birth_order variable;
DATA interwrk.parentchild;
	LENGTH sourcepc $5;
	SET interwrk.parentchild(DROP=birth_order);
	BY pik;
	IF cen00^=1 THEN cen00=0;
	IF cen10^=1 THEN cen10=0;
	%DO yr=2001 %TO &lastacsyear.;
		IF acs&yr.^=1 THEN acs&yr.=0;
	%END;
	sourcepc="";
	IF cen00=1 THEN sourcepc="cen00";
	IF sourcepc="" AND acs2001=1 THEN sourcepc="acs01";
	IF sourcepc="" AND acs2002=1 THEN sourcepc="acs02";
	IF sourcepc="" AND acs2003=1 THEN sourcepc="acs03";
	IF sourcepc="" AND acs2004=1 THEN sourcepc="acs04";
	IF sourcepc="" AND acs2005=1 THEN sourcepc="acs05";
	IF sourcepc="" AND acs2006=1 THEN sourcepc="acs06";
	IF sourcepc="" AND acs2007=1 THEN sourcepc="acs07";
	IF sourcepc="" AND acs2008=1 THEN sourcepc="acs08";
	IF sourcepc="" AND acs2009=1 THEN sourcepc="acs09";
	IF sourcepc="" AND acs2010=1 THEN sourcepc="acs10";
	IF sourcepc="" AND cen10=1 THEN sourcepc="cen10";
	IF sourcepc="" AND acs2011=1 THEN sourcepc="acs11";
	IF sourcepc="" AND acs2012=1 THEN sourcepc="acs12";
	IF sourcepc="" AND acs2013=1 THEN sourcepc="acs13";
	IF sourcepc="" AND acs2014=1 THEN sourcepc="acs14";
	IF sourcepc="" AND acs2015=1 THEN sourcepc="acs15";
	IF sourcepc="" AND acs2016=1 THEN sourcepc="acs16";
	IF sourcepc="" AND acs2017=1 THEN sourcepc="acs17";
	%IF &lastacsyear.=2018 %THEN %DO;
		IF sourcepc="" AND acs2018=1 THEN sourcepc="acs18";
	%END;
	*generate new birth order varibale;
	birth_order+1;
	IF FIRST.pik THEN birth_order=1;
RUN;

PROC FREQ DATA=interwrk.parentchild;
	TITLE "tabulate source of data";
	TABLES sourcepc cen00 cen10 acs2001-acs&lastacsyear. /MISSING;
RUN;

PROC FREQ DATA=interwrk.parentchild;
	TITLE "tabulate key variables and check for missing vlaues";
	TABLES birth_order marital_status hh_head /MISSING;
RUN;

PROC CONTENTS DATA=interwrk.parentchild;
RUN;

PROC PRINT DATA=interwrk.parentchild(OBS=100);
RUN;

%mend finaldata;
%finaldata;
