/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		Calculates summary stats for the universe of establishments that describe the female to male earnings ratio by industry, as well as estimating linear fits of those relationships over time and with respect to the female share of top earners.  Adds an indicator if the top earner at the firm is a parent.  Generates the 2 STATA datesets used for the coworker regression analyses.

	OUTPUT DATASETS:
	       - outputs.f_shr_earn_ind3_wt_reg
	       - for_fig_F_top3_ind3_1995v2017_reg.csv
	       - figures/for_fig_F_top3_ind3_1995v2017.csv
	       - for_fig_F_top3_ind3_reg.csv
	       - for_fig_F_top3_ind3.csv 	   

*********************************************************************************************/


%let outdir = /final;
%let supdir = /final/support;
%let figdatadir = /final/figures;

                 
* 1995 vs 2017 3-digit industry comparison;
* ========================================;                                       
data tmp_out;
    set outputs.f_shr_earner_ind3_95v17_wt;
    where industry_3d ~= "" and industry_3d ~= "927" and industry_3d ~= "482";
                 
    
    top3_F_ratio_1995_rnd = round(top3_F_ratio_1995,0.001);
    top3_F_ratio_2017_rnd = round(top3_F_ratio_2017,0.001);
    chg_top3_F_ratio_17v95_rnd = top3_F_ratio_2017_rnd - top3_F_ratio_1995_rnd;
    f_m_avg_fqearn_ratio_1995_rnd = round(f_m_avg_fqearn_ratio_1995,0.001);
    f_m_avg_fqearn_ratio_2017_rnd = round(f_m_avg_fqearn_ratio_2017,0.001);
    chg_f_m_avg_fqearn_17v95_rnd = f_m_avg_fqearn_ratio_2017_rnd - f_m_avg_fqearn_ratio_1995_rnd;

run;

proc reg data=tmp_out;
    model chg_f_m_avg_fqearn_17v95_rnd = chg_top3_F_ratio_17v95_rnd;
run;                   

    * regression excluding top and bottom 5%;
proc summary data=tmp_out;
    var chg_f_m_avg_fqearn_17v95_rnd   chg_top3_F_ratio_17v95_rnd;
    output out=ind_chg_moments n= p95= p5=  /autoname;
run;
    
proc print data=ind_chg_moments;
    
proc reg data=tmp_out outest=outputs.for_fig_f_top3_ind_1995v2017_reg;
    where -0.042 < chg_f_m_avg_fqearn_17v95_rnd < 0.143 and -0.007 < chg_top3_F_ratio_17v95_rnd < 0.164 ;
    model chg_f_m_avg_fqearn_17v95_rnd = chg_top3_F_ratio_17v95_rnd;
run;    
    
proc print data=outputs.for_fig_f_top3_ind_1995v2017_reg;
                 
proc export data=outputs.for_fig_f_top3_ind_1995v2017_reg(keep=  intercept chg_top3_F_ratio_17v95_rnd )
            outfile="&outdir./for_fig_F_top3_ind3_1995v2017_reg.csv"
            dbms=csv
            replace;
run;
    
proc summary data=tmp_out;
    where -0.042 < chg_f_m_avg_fqearn_17v95_rnd < 0.143 and -0.007 < chg_top3_F_ratio_17v95_rnd < 0.164 ;
    var chg_f_m_avg_fqearn_17v95_rnd;
    output out=ind_chg_moments_less5p n= /autoname;
run;
proc export data=ind_chg_moments_less5p(keep=  chg_f_m_avg_fqearn_17v95_rnd_n )
            outfile="&supdir./for_fig_F_top3_ind3_1995v2017_regcnt.csv"
            dbms=csv
            replace;
run;

          
proc export data=tmp_out(keep= chg_top3_F_ratio_17v95_rnd chg_f_m_avg_fqearn_17v95_rnd industry_3d )
            outfile="&figdatadir./for_fig_F_top3_ind3_1995v2017.csv"
            dbms=csv
            replace;
run;
        
proc export data=tmp_out(keep=chg_top3_F_ratio_17v95_rnd chg_f_m_avg_fqearn_17v95_rnd top3_F_ratio_1995_rnd top3_F_ratio_2017_rnd industry_3d top3_F_ratio_1995 top3_F_ratio_2017 f_m_avg_fqearn_ratio_1995_rnd f_m_avg_fqearn_ratio_2017_rnd f_m_avg_fqearn_ratio_1995 f_m_avg_fqearn_ratio_2017 count_fm_ratio_1995 count_fm_ratio_2017 count_top3_1995 count_top3_2017 )
            outfile="&supdir./for_fig_F_top3_ind3_1995v2017.csv"
            dbms=csv
            replace;
run;                      
                           
* 3-digit industry comparison - full sample;
* ========================================;
proc reg data=outputs.f_shr_earner_ind3_wt;
    where industry_3d ~= "" and top3_F_ratio_mean ~= . and industry_3d ~= "927" and industry_3d ~= "482";
    model f_m_avg_fqearn_ratio_mean = top3_F_ratio_mean;
run;
  
 * regression excluding top and bottom 5 percent;
proc summary data=outputs.f_shr_earner_ind3_wt;
    where industry_3d ~= "" and top3_F_ratio_mean ~= . and industry_3d ~= "927" and industry_3d ~= "482";
    var f_m_avg_fqearn_ratio_mean   top3_F_ratio_mean;
    output out=ind_moments n=  p95= p5=  /autoname;
run;
    
proc print data=ind_moments;
    
proc reg data=outputs.f_shr_earner_ind3_wt outest=outputs.f_shr_earn_ind3_wt_reg  ;
    where industry_3d ~= "" and top3_F_ratio_mean ~= . and industry_3d ~= "927" and industry_3d ~= "482"
          and 0.66180 < f_m_avg_fqearn_ratio_mean < 0.97394 and 0.052626 < top3_F_ratio_mean < 0.43778;
    model f_m_avg_fqearn_ratio_mean = top3_F_ratio_mean;
run;    
        
            
proc print  data=outputs.f_shr_earn_ind3_wt_reg;  
proc export data=outputs.f_shr_earn_ind3_wt_reg(keep=  intercept top3_F_ratio_mean )
            outfile="&outdir./for_fig_F_top3_ind3_reg.csv"
            dbms=csv
            replace;
run;
   
proc summary data=outputs.f_shr_earner_ind3_wt;
    where industry_3d ~= "" and top3_F_ratio_mean ~= . and industry_3d ~= "927" and industry_3d ~= "482"
          and 0.66180 < f_m_avg_fqearn_ratio_mean < 0.97394 and 0.052626 < top3_F_ratio_mean < 0.43778;
    var f_m_avg_fqearn_ratio_mean;
    output out=ind_moments_less5p n= /autoname;
run;
proc export data=ind_moments_less5p(keep=  f_m_avg_fqearn_ratio_mean_n )
            outfile="&supdir./for_fig_F_top3_ind3_regcnt.csv"
            dbms=csv
            replace;
run;   

                                       
data tmp_out;
    set outputs.f_shr_earner_ind3_wt;
    where industry_3d ~= "" and top3_F_ratio_mean ~= . and industry_3d ~= "927" and industry_3d ~= "482";
                 
    
    top3_F_ratio_rnd = round(top3_F_ratio_mean,0.001);
    f_m_avg_fqearn_ratio_rnd = round(f_m_avg_fqearn_ratio_mean,0.001);

run;
                    
          
proc export data=tmp_out(keep=  top3_F_ratio_rnd f_m_avg_fqearn_ratio_rnd industry_3d )
            outfile="&figdatadir./for_fig_F_top3_ind3.csv"
            dbms=csv
            replace;
run;
        
proc export data=tmp_out(keep= top3_F_ratio_rnd top3_F_ratio_mean f_m_avg_fqearn_ratio_rnd f_m_avg_fqearn_ratio_mean  industry_3d top3_f_ratio_n f_m_avg_fqearn_ratio_n )
            outfile="&supdir./for_fig_F_top3_ind3.csv"
            dbms=csv
            replace;
run;                      
                    
