/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Obtains LEHD earnings records for all ACS respondents with occupation codes.
		 Focuses on the earnings at the time of the ACS survey, and then obtains worker
		 and firm characteristics from the LEHD at the time of the survey.  Groups ACS
		 occupation codes into managerial/executive/professional occupations.

	OUTPUT DATASETS:
	       - interwrk.acs_earning_hist
	       - interwrk.acs_occ_earn 
*********************************************************************************************/


%let max_n_fid = 200;
%let num_obs = max;

 * generate ACS survey respondents only version of phf;
     
data acs_phf(drop=rc);
    set lehd_t13.phf_interleave_b (obs=&num_obs. keep=pik fid sein e21-e&last_qtime.);
    where pik ~= "000000000";         
    
    if _n_ = 1 then do;
    
        declare hash occ_h (dataset:"interwrk.occupation",hashexp:16,multidata:'Y');
            occ_h.defineKey('pik');
            occ_h.defineDone();
    
    end;
    
    rc = occ_h.check();
    if rc = 0 then output;
run;
    
    
proc sort data=acs_phf;
    by pik fid;
run;

proc print data=acs_phf (obs = 5);

data interwrk.acs_earning_hist(keep=pik dom_fid dom_sein qtime earn_fq earn_total tenure_bck occ fq_earn_4qma);
    length e1-e20 earn_fq earn_total 5 dom_sein  $12 
           tenure_bck 3 qtime 3
           occ $4;
    set acs_phf;
    by pik fid;
    retain n_fid too_many_fid;

    array earn {&last_qtime.} e1-e&last_qtime.;
    
    array earn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array fqearn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array sein_list {&max_n_fid., &last_qtime.} $12 _temporary_;
                            
    array fid_list{&max_n_fid.} 5 _temporary_;                        
    
    array earn_tot {&last_qtime.} _temporary_;
    array dom_fqearn_lvl {&last_qtime.} _temporary_;
    array fid_dom {&last_qtime.} 5 _temporary_;
                         
                           
            
    if _n_ = 1 then do;
        n_fid = 1;     
 
        declare hash occ_h (dataset:"interwrk.occupation",hashexp:16,multidata:"Y");
            occ_h.defineKey("pik");
            occ_h.defineData("occ","qtime");
            occ_h.defineDone();
    end;
    
    if first.pik then do;
        
        do i = &first_qtime. to &last_qtime.;
            dom_fqearn_lvl{i} = .;
            fid_dom{i} = .;
            earn_tot{i} = 0;
            do j = 1 to n_fid;
                earn_by_fid{j,i} = .;
                fqearn_by_fid{j,i} = .;
                sein_list{j,i} = "";
            end;
        
        end;
                
        do j = 1 to n_fid;
            fid_list{j} = .;     
        end;
        n_fid = 1;
        too_many_fid = 0;
    
    end;
    else if first.fid and n_fid < &max_n_fid. then do;
        if n_fid < &max_n_fid. then do;
            n_fid = n_fid + 1;      
        end;
        else too_many_fid = 1;
    end;
            
    fid_list{n_fid} = fid;
                
    * accumulate earnings across the SEIN associated with the fid;            
    do qt = &first_qtime. to &last_qtime.;
         if earn{qt} > 0 then do;
            earn_by_fid{n_fid,qt} = sum(earn{qt},earn_by_fid{n_fid,qt} );
            sein_list{n_fid,qt} = sein;
            earn_tot{qt} = earn_tot{qt} + earn{qt};                           
         end;                                   
    end;
    
    * identify full-quarter earnings;
    if last.fid  then do;                        
        do qt = &first_qtime. to &last_qtime. - 1;
            if earn_by_fid{n_fid,qt} > 0 then do;
                * if full quarter earnings across all sein for this fid;
                if earn_by_fid{n_fid,qt-1} > 0 and earn_by_fid{n_fid,qt+1} > 0 then do;
   
                    fqearn_by_fid{n_fid,qt} = earn_by_fid{n_fid,qt};
                    * check if this is the dominant earnings;
                    if earn_by_fid{n_fid,qt} > dom_fqearn_lvl{qt} then do;
                        fid_dom{qt} = fid;
                        dom_fqearn_lvl{qt} = earn_by_fid{n_fid,qt};
                    end;
                end;
            end;   
        end;                    
    end;
                    
    if last.pik = 1 and too_many_fid = 0 then do;
   
        rc = occ_h.find();
        do while(rc=0);         
          if &first_qtime.  < qtime < &last_qtime.  then do;

            tenure_bck = .;
            dom_fid = .;
            dom_sein = "";
            earn_fq = .;
            earn_total = .;
                            
            * identify the dominant sein at the birth time (from the dominant fid);
            dom_fid = fid_dom{qtime};               
            do i = 1 to n_fid;
                if dom_fid = fid_list{i} then dom_sein = sein_list{i,qtime};    
            end;

            * if no dominant employer, then select the employer with the higest earnings in that qtime;
            alt_sein_earn = 0;
            if dom_fid = . then do;
                do i = 1 to n_fid;
                    if earn_by_fid{i,qtime} > alt_sein_earn then do;
                        dom_sein = sein_list{i,qtime};
                        dom_fid = fid_list{i};
                        alt_sein_earn = earn_by_fid{i,qtime};
                    end;
                end;
            end;
                        
            * calculate the dominant full-quarter earnings and total earnings +/- 20 quarters fwd and bck from one year before birth;                
            earn_fq = dom_fqearn_lvl{qtime};
            earn_total = earn_tot{qtime};
            
            * calculate tenure back at the dominant employer 1 year before birth;
            do i = 1 to n_fid;
                tenure_bck = .;
                fq_earn_4qma = .;
                if fid_list{i} = dom_fid and dom_fid ~= . then do;
                    if qtime <= &first_qtime. then tenure_bck = .;
                    else do;
                        tenure_bck = 0;
                        do j = 1 to qtime - &first_qtime.;
                            if earn_by_fid{i,qtime-j} > 0 then tenure_bck = tenure_bck + 1;
                        end;
                    end;    
    
                    tot_fq_earn = 0;
                    tot_fq_cnt = 0;
                    do j = 0 to 3;
                        if fqearn_by_fid{i,qtime-j} > 0 then do;
                            tot_fq_earn = tot_fq_earn + fqearn_by_fid{i,qtime-j};
                            tot_fq_cnt = tot_fq_cnt + 1;
                        end;
                    end;
                    if tot_fq_cnt > 0 then fq_earn_4qma = tot_fq_earn / tot_fq_cnt;
                    else fq_earn_4qma = 0;
                end;
            end;

            label tenure_bck = "Workers tenure at dominant SEIN in ACS survey period"
                  dom_sein = "dominant employer SEIN in ACS survey qtime";
                    
            if earn_total > 0 then output;
          end;
            
            rc = occ_h.find_next();
        end;     
    end;

run;  
    
    
proc contents data=interwrk.acs_earning_hist;
proc print data=interwrk.acs_earning_hist(obs=100); 

* merge with icf;
data tmp_worker_acs(drop=year quarter q_date);
    merge interwrk.acs_earning_hist (in=in_acs_earn)
          lehd_t13.icf_us(keep=pik dob dob_imputed educ_c educ_c_imputed ethnicity ethnicity_imputed race race_imputed sex sex_imputed in=in_icf);
    by pik;
        
    if in_acs_earn then do;
        * calculate age;
        year = floor((qtime-1)/4) + 1985;
        quarter = qtime - (year - 1985)*4;
        if quarter = 1      then q_date = mdy(1,1,year);
        else if quarter = 2 then q_date = mdy(4,1,year);
        else if quarter = 3 then q_date = mdy(7,1,year);
        else if quarter = 4 then q_date = mdy(10,1,year);
            
        age = int(intck('MONTH', dob, q_date)/12);
        output;
    end;
run;     
    
    
* merge with SEIN characteristics;
    
    
    
proc sort data=tmp_worker_acs;
    by dom_sein qtime;
run;
        
proc sort data=interwrk.sein_characteristics;
    by sein qtime;
run;
    
data interwrk.acs_occ_earn(drop= fq_earn_4qma_p99 fq_earn_4qma_top1 fq_earn_4qma_top3);
    merge tmp_worker_acs (in=in_acs rename=(dom_sein=sein))
          interwrk.sein_characteristics(keep=sein qtime firmage firmsize allemp_avg_fq_earn_4qma fq_earn_4qma_n fq_earn_4qma_p90 fq_earn_4qma_p95 fq_earn_4qma_p99 fq_earn_4qma_top1 fq_earn_4qma_top3 naics);
    by sein qtime;
    
    if in_acs then do;
        is_p90_fq_earn = 0;
        is_p95_fq_earn = 0;
        is_p99_fq_earn = 0;
        is_top1_fq_earn = 0;
        is_top3_fq_earn = 0;
        is_above_avg_fq_earn = 0;
              
        if fq_earn_4qma >= fq_earn_4qma_p90 and fq_earn_4qma_p90 > 0 then is_p90_fq_earn = 1; 
        if fq_earn_4qma >= fq_earn_4qma_p95 and fq_earn_4qma_p95 > 0 then is_p95_fq_earn = 1; 
        if fq_earn_4qma >= fq_earn_4qma_p99 and fq_earn_4qma_p99 > 0 then is_p99_fq_earn = 1; 
        if fq_earn_4qma >= fq_earn_4qma_top1 and fq_earn_4qma_top1 > 0 then is_top1_fq_earn = 1; 
        if fq_earn_4qma >= fq_earn_4qma_top3 and fq_earn_4qma_top3 > 0 then is_top3_fq_earn = 1;
        if fq_earn_4qma >= allemp_avg_fq_earn_4qma and allemp_avg_fq_earn_4qma > 0 then is_above_avg_fq_earn = 1;  


        
        * set to missing the military and unemployed occupation codes;
        if substr(occ,1,2) = "98" or substr(occ,1,2) = "99" then occ="";
                  
        occ_3d = substr(occ,1,3);
        
        * Assign managerial occupation groupings;
        if occ_3d in ("001","002","003","004","005","006","010","011",
                      "012","013","014","015","016","020","021","022",
                      "023","030","031","033","034","035","036","041",
                      "042","043") then occ_type = "Exec or Manager";
        else if occ_3d in ("080","130","210","301","306") 
             then occ_type = "Professional";
        else if occ_3d in ("370","371","372","373","401","420","421",
                           "430","432","470","471","500","600","620",
                           "700","770","900") then occ_type = "Supervisor";
        else occ_type = occ_3d;
        
        
            
        output;
    end;
run;

proc contents data=interwrk.acs_occ_earn;
proc print data=interwrk.acs_occ_earn(obs=20);
